## 0.3.0

- Complete API rewrite, "list" methods return an iterator over resources, "get" method returns a resource 
- Handles all GET endpoints (except the new "Provisioning" section)
- Handle pagination
- Handle downloading Finance and Sales reports

## 0.2.1

Bugfixes:

  - cryptography dependency is required

## 0.2.0

Features:

  - Added more functions (@fehmitoumi)

## 0.1.0

Features:

  - Initial Release